#!/usr/bin/env python
import os
from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()

setup(
    name='lens_csv',
    author='Veit Heller',
    version='0.0.3',
    license='MIT',
    url='https://github.com/port-zero/lens_csv',
    download_url = 'https://github.com/port-zero/lens_csv/tarball/0.0.3',
    description='A CSV parser for lens',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages('.'),
    install_requires=[
        "pygments",
        "lens-cli",
    ],
)




import csv
from io import StringIO

from lens.parsers.base import LensParser

class Parser(LensParser):
    def treat(self, inpt, keys):
        f = StringIO(inpt)
        dialect = csv.Sniffer().sniff(f.read(1024))
        f.seek(0)
        loaded = list(csv.reader(f, dialect))

        for key in keys:
            loaded = loaded[key]

        return str(loaded)
